@@ -32,7 +32,6 @@
 #include <kpluginfactory.h>
 #include <kaboutdata.h>
 
-#include <kglobalsettings.h>
 #include <kprotocolmanager.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
@@ -46,14 +45,16 @@
 #include <KIO/FileUndoManager>
 #include <KJobWidgets>
 #include <ktoolinvocation.h>
+#include <kconfig.h>
 #include <kconfiggroup.h>
-#include <KDebug>
-
+#include <ksharedconfig.h>
 #include <KLocalizedString>
 
 #include <QApplication>
 #include <QMimeData>
 
+#include "fsviewdebug.h"
+
 K_PLUGIN_FACTORY(FSViewPartFactory, registerPlugin<FSViewPart>();)
 
 // FSJob, for progress
@@ -62,8 +63,7 @@ FSJob::FSJob(FSView *v)
     : KIO::Job()
 {
     _view = v;
-    QObject::connect(v, SIGNAL(progress(int,int,QString)),
-                     this, SLOT(progressSlot(int,int,QString)));
+    connect(v, &FSView::progress, this, &FSJob::progressSlot);
 }
 
 void FSJob::kill(bool /*quietly*/)
@@ -136,33 +136,25 @@ FSViewPart::FSViewPart(QWidget *parentWidget,
     action->setToolTip(i18n("Show FSView manual"));
     action->setWhatsThis(i18n("Opens the help browser with the "
                               "FSView documentation"));
-    connect(action, SIGNAL(triggered()), this, SLOT(showHelp()));
+    connect(action, &QAction::triggered, this, &FSViewPart::showHelp);
 
-    QObject::connect(_visMenu->menu(), SIGNAL(aboutToShow()),
-                     SLOT(slotShowVisMenu()));
-    QObject::connect(_areaMenu->menu(), SIGNAL(aboutToShow()),
-                     SLOT(slotShowAreaMenu()));
-    QObject::connect(_depthMenu->menu(), SIGNAL(aboutToShow()),
-                     SLOT(slotShowDepthMenu()));
-    QObject::connect(_colorMenu->menu(), SIGNAL(aboutToShow()),
-                     SLOT(slotShowColorMenu()));
+    connect(_visMenu->menu(), &QMenu::aboutToShow,this, &FSViewPart::slotShowVisMenu);
+    connect(_areaMenu->menu(), &QMenu::aboutToShow, this, &FSViewPart::slotShowAreaMenu);
+    connect(_depthMenu->menu(), &QMenu::aboutToShow, this, &FSViewPart::slotShowDepthMenu);
+    connect(_colorMenu->menu(), &QMenu::aboutToShow, this, &FSViewPart::slotShowColorMenu);
 
-    slotSettingsChanged(KGlobalSettings::SETTINGS_MOUSE);
-    connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)),
-            SLOT(slotSettingsChanged(int)));
+    // Both of these click signals are connected.  Whether a single or
+    // double click activates an item is checked against the current
+    // style setting when the click happens.
+    connect(_view, &FSView::clicked, _ext, &FSViewBrowserExtension::itemSingleClicked);
+    connect(_view, &FSView::doubleClicked, _ext, &FSViewBrowserExtension::itemDoubleClicked);
 
-    QObject::connect(_view, SIGNAL(returnPressed(TreeMapItem*)),
-                     _ext, SLOT(selected(TreeMapItem*)));
-    QObject::connect(_view, SIGNAL(selectionChanged()),
-                     this, SLOT(updateActions()));
-    QObject::connect(_view,
-                     SIGNAL(contextMenuRequested(TreeMapItem*,QPoint)),
-                     this,
-                     SLOT(contextMenu(TreeMapItem*,QPoint)));
+    connect(_view, &TreeMapWidget::returnPressed, _ext, &FSViewBrowserExtension::selected);
+    connect(_view, QOverload<>::of(&TreeMapWidget::selectionChanged), this, &FSViewPart::updateActions);
+    connect(_view, &TreeMapWidget::contextMenuRequested, this, &FSViewPart::contextMenu);
 
-    QObject::connect(_view, SIGNAL(started()), this, SLOT(startedSlot()));
-    QObject::connect(_view, SIGNAL(completed(int)),
-                     this, SLOT(completedSlot(int)));
+    connect(_view, &FSView::started, this, &FSViewPart::startedSlot);
+    connect(_view, &FSView::completed, this, &FSViewPart::completedSlot);
 
     // Create common file management actions - this is necessary in KDE4
     // as these common actions are no longer automatically part of KParts.
@@ -177,24 +169,23 @@ FSViewPart::FSViewPart(QWidget *parentWidget,
     moveToTrashAction->setText(i18nc("@action:inmenu File", "Move to Trash"));
     moveToTrashAction->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
     actionCollection()->setDefaultShortcut(moveToTrashAction, QKeySequence(QKeySequence::Delete));
-    connect(moveToTrashAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)),
-            _ext, SLOT(trash(Qt::MouseButtons,Qt::KeyboardModifiers)));
+    connect(moveToTrashAction, &QAction::triggered, _ext, &FSViewBrowserExtension::trash);
 
     QAction *deleteAction = actionCollection()->addAction(QStringLiteral("delete"));
     deleteAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     deleteAction->setText(i18nc("@action:inmenu File", "Delete"));
     actionCollection()->setDefaultShortcut(deleteAction, QKeySequence(Qt::SHIFT | Qt::Key_Delete));
-    connect(deleteAction, SIGNAL(triggered()), _ext, SLOT(del()));
+    connect(deleteAction, &QAction::triggered, _ext, &FSViewBrowserExtension::del);
 
     QAction *editMimeTypeAction = actionCollection()->addAction(QStringLiteral("editMimeType"));
     editMimeTypeAction->setText(i18nc("@action:inmenu Edit", "&Edit File Type..."));
-    connect(editMimeTypeAction, SIGNAL(triggered()), _ext, SLOT(editMimeType()));
+    connect(editMimeTypeAction, &QAction::triggered, _ext, &FSViewBrowserExtension::editMimeType);
 
     QAction *propertiesAction = actionCollection()->addAction(QStringLiteral("properties"));
     propertiesAction->setText(i18nc("@action:inmenu File", "Properties"));
     propertiesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     propertiesAction->setShortcut(Qt::ALT | Qt::Key_Return);
-    connect(propertiesAction, SIGNAL(triggered()), SLOT(slotProperties()));
+    connect(propertiesAction, &QAction::triggered, this, &FSViewPart::slotProperties);
 
     QTimer::singleShot(1, this, SLOT(showInfo()));
 
@@ -205,31 +196,12 @@ FSViewPart::FSViewPart(QWidget *parentWidget,
 
 FSViewPart::~FSViewPart()
 {
-    kDebug(90100) << "FSViewPart Destructor";
+    qCDebug(FSVIEWLOG);
 
     delete _job;
     _view->saveFSOptions();
 }
 
-void FSViewPart::slotSettingsChanged(int category)
-{
-    if (category != KGlobalSettings::SETTINGS_MOUSE) {
-        return;
-    }
-
-    QObject::disconnect(_view, SIGNAL(clicked(TreeMapItem*)),
-                        _ext, SLOT(selected(TreeMapItem*)));
-    QObject::disconnect(_view, SIGNAL(doubleClicked(TreeMapItem*)),
-                        _ext, SLOT(selected(TreeMapItem*)));
-
-    if (_view->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick))
-        QObject::connect(_view, SIGNAL(clicked(TreeMapItem*)),
-                         _ext, SLOT(selected(TreeMapItem*)));
-    else
-        QObject::connect(_view, SIGNAL(doubleClicked(TreeMapItem*)),
-                         _ext, SLOT(selected(TreeMapItem*)));
-}
-
 void FSViewPart::showInfo()
 {
     QString info;
@@ -262,7 +234,7 @@ void FSViewPart::completedSlot(int dirs)
         _job = nullptr;
     }
 
-    KConfigGroup cconfig(_view->config(), "MetricCache");
+    KConfigGroup cconfig = _view->config()->group("MetricCache");
     _view->saveMetric(&cconfig);
 
     emit completed();
@@ -294,7 +266,7 @@ void FSViewPart::slotShowColorMenu()
 
 bool FSViewPart::openFile() // never called since openUrl is reimplemented
 {
-    kDebug(90100) << "FSViewPart::openFile " << localFilePath();
+    qCDebug(FSVIEWLOG) << localFilePath();
     _view->setPath(localFilePath());
 
     return true;
@@ -302,7 +274,7 @@ bool FSViewPart::openFile() // never called since openUrl is reimplemented
 
 bool FSViewPart::openUrl(const QUrl &url)
 {
-    kDebug(90100) << "FSViewPart::openUrl " << url.path();
+    qCDebug(FSVIEWLOG) << url.path();
 
     if (!url.isValid()) {
         return false;
@@ -321,7 +293,7 @@ bool FSViewPart::openUrl(const QUrl &url)
 
 bool FSViewPart::closeUrl()
 {
-    kDebug(90100) << "FSViewPart::closeUrl ";
+    qCDebug(FSVIEWLOG);
 
     _view->stop();
 
@@ -369,7 +341,7 @@ void FSViewPart::updateActions()
         stateChanged(QStringLiteral("has_no_selection"));
     }
 
-    kDebug(90100) << "FSViewPart::updateActions, deletable " << canDel;
+    qCDebug(FSVIEWLOG) << "deletable" << canDel;
 }
 
 void FSViewPart::contextMenu(TreeMapItem * /*item*/, const QPoint &p)
@@ -471,14 +443,13 @@ void FSViewBrowserExtension::del()
         KIO::Job *job = KIO::del(urls);
         KJobWidgets::setWindow(job, _view);
         job->uiDelegate()->setAutoErrorHandlingEnabled(true);
-        connect(job, SIGNAL(result(KJob*)),
-                this, SLOT(refresh()));
+        connect(job, &KJob::result, this, &FSViewBrowserExtension::refresh);
     }
 }
 
-void FSViewBrowserExtension::trash(Qt::MouseButtons, Qt::KeyboardModifiers modifiers)
+void FSViewBrowserExtension::trash()
 {
-    bool deleteNotTrash = ((modifiers & Qt::ShiftModifier) != 0);
+    bool deleteNotTrash = ((QGuiApplication::keyboardModifiers() & Qt::ShiftModifier) != 0);
     if (deleteNotTrash) {
         del();
     } else {
@@ -491,8 +462,7 @@ void FSViewBrowserExtension::trash(Qt::MouseButtons, Qt::KeyboardModifiers modif
             KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Trash, urls, QUrl("trash:/"), job);
             KJobWidgets::setWindow(job, _view);
             job->uiDelegate()->setAutoErrorHandlingEnabled(true);
-            connect(job, SIGNAL(result(KJob*)),
-                    this, SLOT(refresh()));
+            connect(job, &KJob::result, this, &FSViewBrowserExtension::refresh);
         }
     }
 }
@@ -530,12 +500,27 @@ void FSViewBrowserExtension::refresh()
         }
     }
 
-    kDebug(90100) << "FSViewPart::refreshing "
-                  << ((Inode *)commonParent)->path() << endl;
+    qCDebug(FSVIEWLOG) << "refreshing"
+                       << ((Inode *)commonParent)->path() << endl;
 
     _view->requestUpdate((Inode *)commonParent);
 }
 
+void FSViewBrowserExtension::itemSingleClicked(TreeMapItem *i)
+{
+    if (_view->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick)) {
+        selected(i);
+    }
+}
+
+
+void FSViewBrowserExtension::itemDoubleClicked(TreeMapItem *i)
+{
+    if (!_view->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick)) {
+        selected(i);
+    }
+}
+
 void FSViewBrowserExtension::selected(TreeMapItem *i)
 {
     if (!i) {
